A small example adjacency matrix used for fitting Conditional
Autoregressive (CAR) random effects on the **province** level.
Pairs with data_fhnorm and data_betalogitnorm, whose
province column has matching labels.
A small example adjacency matrix used for fitting Conditional
Autoregressive (CAR) random effects on the **province** level.
Pairs with data_fhnorm and data_betalogitnorm, whose
province column has matching labels.