data_betalogitnorm: Simulation Data for Beta Logit Normal Model
Description
The data_betalogitnorm is a simulation data created specifically to demonstrate the implementation of
Hierarchical Bayesian Small Area Estimation (HB SAE) with Beta distribution.
This data is suitable for testing Beta regression models with a hierarchical structure
between areas. This data is also equipped with variables that apply spatial effects.
Usage
data_betalogitnorm
Arguments
Format
A data frame with 100 rows and 9 variables:
y
Response variable - The proportion of simulation results, has a value between 0 and 1, follows a Beta distribution.
theta
True latent mean parameter on the logit scale, representing the underlying probability of success in each area.
x1, x2, x3
Predictors Variables
n
The number of sample units for each region used in the survey
deff
Design Effect
group
Area ID (1–100) Random effects formula specifying the grouping structure in the data.
sre
An optional grouping factor mapping observations to spatial locations.