This dataset is a simulated data created for demonstrating the implementation of Hierarchical Bayesian Small Area Estimation (HB SAE) using a lognormal-lognormal model. It includes area-level covariates, random effects, direct estimates, and spatial components, for testing SAE models with lognormal assumptions and spatial correlation.
data_lnlnA data frame with 100 rows and 13 variables:
Area ID (1–100) for random effects formula specifying the grouping structure in the data.
Auxiliary area-level covariates
True unstructured area-level random effect on the log scale.
True linear predictor on the log scale (meanlog for lognormal distribution).
True mean on the original scale, calculated from eta_true and sigma_e.
Sample size per area.
Simulated observed mean per area, generated from a lognormal distribution.
Direct estimator of the mean per area (same as y_obs).
Log-transformed direct estimator.
Approximate sampling variance of y_obs.
An optional grouping factor mapping observations to spatial locations.