Learn R Programming

hbsaems (version 0.1.1)

print.hbmc_results: Print a summary for a model goodness of fit and prior sensitivity

Description

Print a summary for a model goodness of fit and prior sensitivity

Usage

# S3 method for hbmc_results
print(x, ...)

Value

Summary of a model goodness of fit and prior sensitivity

Arguments

x

A hbmc_results object

...

Other potential arguments