summary.hbmc_results: Create a summary of a model goodness of fit and prior sensitivity
Description
Create a summary of a model goodness of fit and prior sensitivity
Usage
# S3 method for hbmc_results
summary(object, ...)
Value
Summary of a model goodness of fit and prior sensitivity
Arguments
- object
A hbmc_results object
- ...
Other potential arguments