Learn R Programming

hbsaems (version 0.1.1)

summary.hbmfit: Create a summary of a fitted model represented by a hbmfit object

Description

Create a summary of a fitted model represented by a hbmfit object

Usage

# S3 method for hbmfit
summary(object, ...)

Value

Summary of the model

Arguments

object

A hbmfit object

...

Other potential arguments