print.hbmfit: Print a summary for a fitted model represented by a hbmfit object
Description
Print a summary for a fitted model represented by a hbmfit object
Usage
# S3 method for hbmfit
print(x, ...)
Value
Summary of the model
Arguments
- x
A hbmfit object (changed from object to x for consistency with generic)
- ...
Other potential arguments