Learn R Programming

hbsaems (version 0.1.1)

run_sae_app: Launch the Shiny App for Small Area Estimation using Hierarchical Bayesian

Description

This function launches an interactive Shiny application for performing Hierarchical Bayesian Small Area Estimation (HBSAE) using the brms package with Stan as the backend for Bayesian inference.

Usage

run_sae_app()

Arguments

Value

Opens a Shiny app in the web browser. The function does not return a value.

Author

Achmad Syahrul Choir and Arsyka Laila Oktalia Siregar

References

Rao, J. N. K., & Molina, I. (2015). Small Area Estimation. John Wiley & Sons.

Examples

Run this code
# Launch the HBSAE Shiny application (run interactively only)
if (interactive()) {
  run_sae_app()
}

# The function will open an interactive web application in your default browser
# where you can:
# 1. Upload your small area data
# 2. Specify model parameters 
# 3. Run Hierarchical Bayesian analysis
# 4. View and download results
# Note: This function requires an interactive R session
# and will open a web browser to display the Shiny application


Run the code above in your browser using DataLab